==> xemacs-packages-10.0.tbz: lib/xemacs/xemacs-packages/lisp/gnus/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'gnus-start '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus" "nnheader"))
(custom-add-loads 'gnus-exit '("gnus-group" "gnus"))
(custom-add-loads 'message '("message" "mml"))
(custom-add-loads 'mm-url '("mm-url"))
(custom-add-loads 'gnus-fun '("gnus-fun"))
(custom-add-loads 'nndiary '("nndiary"))
(custom-add-loads 'gnus-score-expire '("gnus-kill" "gnus-score"))
(custom-add-loads 'gnus-score-kill '("gnus-kill" "gnus"))
(custom-add-loads 'mime '("mailcap" "mm-bodies" "mm-encode" "mm-util" "rfc1843"))
(custom-add-loads 'gnus-message '("gnus-msg" "message" "gnus"))
(custom-add-loads 'mime-security '("gnus-art" "mm-decode"))
(custom-add-loads 'gnus-summary-sort '("gnus-sum"))
(custom-add-loads 'nnmail-procmail '("nnmail"))
(custom-add-loads 'gpg-commands-key '("gpg"))
(custom-add-loads 'gnus-registry '("gnus-registry"))
(custom-add-loads 'gnus-article-buttons '("gnus-art"))
(custom-add-loads 'gnus-extract-archive '("gnus-uu"))
(custom-add-loads 'gnus-article-headers '("gnus-art" "gnus-fun" "gnus-sum"))
(custom-add-loads 'gnus-score '("gnus-nocem" "gnus"))
(custom-add-loads 'gnus-summary-various '("gnus-sum"))
(custom-add-loads 'gnus-topic '("gnus-topic"))
(custom-add-loads 'gnus-article-emphasis '("gnus-art"))
(custom-add-loads 'earcon '("earcon"))
(custom-add-loads 'gnus-group-foreign '("gnus-group" "gnus-msg"))
(custom-add-loads 'gnus-undo '("gnus-undo"))
(custom-add-loads 'gnus-article-washing '("gnus-art"))
(custom-add-loads 'mail '("gnus" "imap" "message" "mm-decode"))
(custom-add-loads 'gnus-summary-exit '("gnus-sum" "gnus"))
(custom-add-loads 'gnus-article-saving '("gnus-art" "gnus"))
(custom-add-loads 'gnus-extract-view '("gnus-sum" "gnus-uu"))
(custom-add-loads 'canlock '("canlock"))
(custom-add-loads 'gnus-group-listing '("gnus-group"))
(custom-add-loads 'gnus-summary '("gnus-sum" "gnus"))
(custom-add-loads 'message-headers '("message"))
(custom-add-loads 'spam-report '("spam-report"))
(custom-add-loads 'gnus-group-select '("gnus-group" "gnus-sum" "gnus"))
(custom-add-loads 'mailcap '("mailcap"))
(custom-add-loads 'gnus-score-various '("gnus-score" "gnus"))
(custom-add-loads 'gpg '("gpg-ring" "gpg"))
(custom-add-loads 'gnus-server '("gnus-srvr" "gnus" "nnheader"))
(custom-add-loads 'gnus-meta '("gnus"))
(custom-add-loads 'nnimap '("nnimap"))
(custom-add-loads 'gnus-server-visual '("gnus-srvr"))
(custom-add-loads 'gpg-commands '("gpg"))
(custom-add-loads 'gnus-summary-mail '("gnus-sum"))
(custom-add-loads 'gnus-score-default '("gnus-score" "gnus-sum"))
(custom-add-loads 'nnmail-expire '("nnmail"))
(custom-add-loads 'gnus-thread '("gnus-group" "gnus-sum"))
(custom-add-loads 'gnus-nocem '("gnus-nocem"))
(custom-add-loads 'gnus-threading '("gnus-sum"))
(custom-add-loads 'applications '("canlock"))
(custom-add-loads 'gnus-summary-maneuvering '("gnus-sum"))
(custom-add-loads 'gnus-charset '("gnus-group" "gnus-sum" "gnus"))
(custom-add-loads 'gnus-extract '("binhex" "gnus" "gnus-uu" "uudecode"))
(custom-add-loads 'gnus-summary-tree '("gnus-salt"))
(custom-add-loads 'mime-display '("mm-decode"))
(custom-add-loads 'nnmail-split '("nndiary" "nnmail"))
(custom-add-loads 'gnus-dribble-file '("gnus-start"))
(custom-add-loads 'gnus-format '("gnus-spec"))
(custom-add-loads 'gnus-article-various '("gnus-art" "gnus-sum"))
(custom-add-loads 'gnus-group-new '("gnus-start"))
(custom-add-loads 'message-sending '("message"))
(custom-add-loads 'gpg-options '("gpg"))
(custom-add-loads 'gnus-article '("gnus-art" "gnus-cite"))
(custom-add-loads 'gnus-outlook-deuglify '("deuglify"))
(custom-add-loads 'gnus-agent '("gnus-agent" "gnus"))
(custom-add-loads 'spam '("spam"))
(custom-add-loads 'gnus '("gnus-delay" "gnus-art" "gnus-async" "gnus-demon" "gnus-dup" "gnus-eform" "gnus" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "mail-source" "mm-url" "nnimap" "nnmail" "spam-stat"))
(custom-add-loads 'gnus-xmas '("gnus-xmas"))
(custom-add-loads 'nnmail '("nnmail"))
(custom-add-loads 'mail-source '("mail-source" "nndiary"))
(custom-add-loads 'gnus-article-hiding '("gnus-art" "gnus-cite" "gnus-sum"))
(custom-add-loads 'nnmail-duplicate '("nnmail"))
(custom-add-loads 'gnus-summary-visual '("gnus-sum" "gnus"))
(custom-add-loads 'gnus-group-various '("gnus-group" "gnus-start" "gnus"))
(custom-add-loads 'nnmail-retrieve '("nnmail"))
(custom-add-loads 'multimedia '("gnus-audio" "mm-decode"))
(custom-add-loads 'message-interface '("message"))
(custom-add-loads 'gnus-group '("gnus-topic" "gnus"))
(custom-add-loads 'gnus-article-signature '("gnus-art"))
(custom-add-loads 'gnus-duplicate '("gnus-dup"))
(custom-add-loads 'gnus-score-adapt '("gnus-score" "gnus"))
(custom-add-loads 'nnmail-various '("nnmail"))
(custom-add-loads 'nnmail-files '("nnmail"))
(custom-add-loads 'gnus-asynchronous '("gnus-async"))
(custom-add-loads 'gnus-group-visual '("gnus-group" "gnus"))
(custom-add-loads 'gnus-visual '("earcon" "gnus-art" "gnus-audio" "gnus" "smiley"))
(custom-add-loads 'message-forwarding '("message"))
(custom-add-loads 'message-news '("message"))
(custom-add-loads 'gnus-edit-form '("gnus-eform"))
(custom-add-loads 'gnus-delay '("gnus-delay"))
(custom-add-loads 'gnus-files '("gnus" "nnmail"))
(custom-add-loads 'gnus-summary-pick '("gnus-salt"))
(custom-add-loads 'gnus-cite '("gnus-cite"))
(custom-add-loads 'gnus-demon '("gnus-demon"))
(custom-add-loads 'gnus-summary-choose '("gnus-sum"))
(custom-add-loads 'gnus-windows '("gnus-win"))
(custom-add-loads 'message-mail '("message"))
(custom-add-loads 'gnus-newsrc '("gnus-start"))
(custom-add-loads 'message-various '("message"))
(custom-add-loads 'gnus-group-levels '("gnus-group" "gnus-start" "gnus"))
(custom-add-loads 'gnus-summary-format '("gnus-diary" "gnus-sum" "gnus"))
(custom-add-loads 'gnus-score-decay '("gnus-score"))
(custom-add-loads 'gpg-ring '("gpg-ring"))
(custom-add-loads 'gnus-sieve '("gnus-sieve"))
(custom-add-loads 'gnus-extract-post '("gnus-uu"))
(custom-add-loads 'smime '("smime"))
(custom-add-loads 'faces '("gnus" "message"))
(custom-add-loads 'gnus-audio '("gnus-audio"))
(custom-add-loads 'spam-ifile '("spam"))
(custom-add-loads 'gnus-various '("gnus-sum" "gnus-util" "gnus"))
(custom-add-loads 'gnus-group-icons '("gnus-group"))
(custom-add-loads 'smiley '("smiley"))
(custom-add-loads 'gnus-start-server '("gnus-start"))
(custom-add-loads 'gnus-article-highlight '("gnus-art"))
(custom-add-loads 'processes '("gpg"))
(custom-add-loads 'news '("gnus" "message" "mm-decode"))
(custom-add-loads 'spam-bogofilter '("spam"))
(custom-add-loads 'gnus-diary '("gnus-diary" "nndiary"))
(custom-add-loads 'gnus-picon '("gnus-art" "gnus-picon"))
(custom-add-loads 'gnus-cache '("gnus-cache" "gnus"))
(custom-add-loads 'message-insertion '("message"))
(custom-add-loads 'message-faces '("message"))
(custom-add-loads 'gnus-score-files '("gnus-score" "gnus"))
(custom-add-loads 'spam-stat '("spam-stat"))
(custom-add-loads 'gnus-summary-marks '("gnus-sum" "gnus"))
(custom-add-loads 'nnmail-prepare '("nnmail"))
(custom-add-loads 'message-buffers '("message"))
(custom-add-loads 'gnus-article-mime '("gnus-art" "gnus-sum" "mm-uu"))
(custom-add-loads 'imap '("imap"))

;;; custom-load.el ends here

==> xemacs-packages-13.1.tbz: lib/xemacs/xemacs-packages/lisp/gnus/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'gnus-start '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus" "nnheader"))
(custom-add-loads 'gnus-exit '("gnus-group" "gnus"))
(custom-add-loads 'message '("message" "mml-sec" "mml"))
(custom-add-loads 'mm-url '("mm-url"))
(custom-add-loads 'gnus-fun '("gnus-fun"))
(custom-add-loads 'nndiary '("nndiary"))
(custom-add-loads 'gnus-score-expire '("gnus-kill" "gnus-score"))
(custom-add-loads 'gnus-score-kill '("gnus-kill" "gnus"))
(custom-add-loads 'mime '("mailcap" "mm-bodies" "mm-encode" "mm-util" "rfc1843"))
(custom-add-loads 'gnus-message '("gnus-msg" "message" "gnus"))
(custom-add-loads 'mime-security '("gnus-art" "mm-decode" "mml2015"))
(custom-add-loads 'gnus-summary-sort '("gnus-sum"))
(custom-add-loads 'nnmail-procmail '("nnmail"))
(custom-add-loads 'spam-spamoracle '("spam"))
(custom-add-loads 'gpg-commands-key '("gpg"))
(custom-add-loads 'gnus-registry '("gnus-registry"))
(custom-add-loads 'gnus-article-buttons '("gnus-art"))
(custom-add-loads 'gnus-extract-archive '("gnus-uu"))
(custom-add-loads 'gnus-article-headers '("gnus-art" "gnus-fun" "gnus-sum"))
(custom-add-loads 'gnus-score '("gnus-nocem" "gnus"))
(custom-add-loads 'gnus-summary-various '("gnus-sum"))
(custom-add-loads 'gnus-topic '("gnus-topic"))
(custom-add-loads 'gnus-article-emphasis '("gnus-art"))
(custom-add-loads 'earcon '("earcon"))
(custom-add-loads 'gnus-group-foreign '("gnus-group" "gnus-msg"))
(custom-add-loads 'gnus-undo '("gnus-undo"))
(custom-add-loads 'gnus-article-washing '("gnus-art"))
(custom-add-loads 'mail '("gnus" "imap" "message" "mm-decode"))
(custom-add-loads 'gnus-summary-exit '("gnus-sum" "gnus"))
(custom-add-loads 'gnus-article-saving '("gnus-art" "gnus"))
(custom-add-loads 'gnus-extract-view '("gnus-sum" "gnus-uu"))
(custom-add-loads 'canlock '("canlock"))
(custom-add-loads 'gnus-group-listing '("gnus-group"))
(custom-add-loads 'gnus-summary '("gnus-sum" "gnus"))
(custom-add-loads 'message-headers '("message"))
(custom-add-loads 'spam-report '("spam-report"))
(custom-add-loads 'gnus-group-select '("gnus-group" "gnus-sum" "gnus"))
(custom-add-loads 'mailcap '("mailcap"))
(custom-add-loads 'gnus-score-various '("gnus-score" "gnus"))
(custom-add-loads 'gpg '("gpg-ring" "gpg"))
(custom-add-loads 'gnus-server '("gnus-srvr" "gnus" "nnheader"))
(custom-add-loads 'gnus-meta '("gnus"))
(custom-add-loads 'nnimap '("nnimap"))
(custom-add-loads 'gnus-server-visual '("gnus-srvr"))
(custom-add-loads 'gpg-commands '("gpg"))
(custom-add-loads 'gnus-summary-mail '("gnus-sum"))
(custom-add-loads 'gnus-score-default '("gnus-score" "gnus-sum"))
(custom-add-loads 'nnmail-expire '("nnmail"))
(custom-add-loads 'gnus-thread '("gnus-group" "gnus-sum"))
(custom-add-loads 'gnus-nocem '("gnus-nocem"))
(custom-add-loads 'gnus-threading '("gnus-sum"))
(custom-add-loads 'applications '("canlock"))
(custom-add-loads 'gnus-summary-maneuvering '("gnus-sum"))
(custom-add-loads 'gnus-charset '("gnus-group" "gnus-sum" "gnus"))
(custom-add-loads 'gnus-extract '("binhex" "gnus" "gnus-uu" "uudecode"))
(custom-add-loads 'gnus-summary-tree '("gnus-salt"))
(custom-add-loads 'mime-display '("flow-fill" "mm-decode"))
(custom-add-loads 'nnmail-split '("nndiary" "nnmail"))
(custom-add-loads 'gnus-dribble-file '("gnus-start"))
(custom-add-loads 'gnus-format '("gnus-spec"))
(custom-add-loads 'gnus-article-various '("gnus-art" "gnus-sum"))
(custom-add-loads 'gnus-group-new '("gnus-start"))
(custom-add-loads 'message-sending '("message"))
(custom-add-loads 'gpg-options '("gpg"))
(custom-add-loads 'gnus-article '("gnus-art" "gnus-cite"))
(custom-add-loads 'gnus-outlook-deuglify '("deuglify"))
(custom-add-loads 'gnus-agent '("gnus-agent" "gnus"))
(custom-add-loads 'spam '("spam"))
(custom-add-loads 'gnus '("gnus-delay" "gnus-art" "gnus-async" "gnus-demon" "gnus-dup" "gnus-eform" "gnus" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "mail-source" "mm-url" "nnimap" "nnmail" "nntp" "spam-stat"))
(custom-add-loads 'gnus-xmas '("gnus-xmas"))
(custom-add-loads 'nnmail '("nnmail"))
(custom-add-loads 'mail-source '("mail-source" "nndiary"))
(custom-add-loads 'gnus-article-hiding '("gnus-art" "gnus-cite" "gnus-sum"))
(custom-add-loads 'nnmail-duplicate '("nnmail"))
(custom-add-loads 'gnus-summary-visual '("gnus-sum" "gnus"))
(custom-add-loads 'gnus-group-various '("gnus-group" "gnus-start" "gnus"))
(custom-add-loads 'nnmail-retrieve '("nnmail"))
(custom-add-loads 'multimedia '("gnus-audio" "mm-decode"))
(custom-add-loads 'message-interface '("message"))
(custom-add-loads 'gnus-group '("gnus-topic" "gnus"))
(custom-add-loads 'gnus-article-signature '("gnus-art"))
(custom-add-loads 'gnus-duplicate '("gnus-dup"))
(custom-add-loads 'gnus-score-adapt '("gnus-score" "gnus"))
(custom-add-loads 'nnmail-various '("nnmail"))
(custom-add-loads 'nnmail-files '("nnmail"))
(custom-add-loads 'gnus-asynchronous '("gnus-async"))
(custom-add-loads 'gnus-group-visual '("gnus-group" "gnus"))
(custom-add-loads 'gnus-visual '("earcon" "gnus-art" "gnus-audio" "gnus" "smiley"))
(custom-add-loads 'message-forwarding '("message"))
(custom-add-loads 'message-news '("message"))
(custom-add-loads 'gnus-edit-form '("gnus-eform"))
(custom-add-loads 'gnus-delay '("gnus-delay"))
(custom-add-loads 'nntp '("nntp"))
(custom-add-loads 'gnus-files '("gnus" "nnmail"))
(custom-add-loads 'nnir '("nnir"))
(custom-add-loads 'gnus-summary-pick '("gnus-salt"))
(custom-add-loads 'gnus-cite '("gnus-cite"))
(custom-add-loads 'gnus-demon '("gnus-demon"))
(custom-add-loads 'gnus-summary-choose '("gnus-sum"))
(custom-add-loads 'gnus-windows '("gnus-win"))
(custom-add-loads 'message-mail '("message"))
(custom-add-loads 'gnus-newsrc '("gnus-start"))
(custom-add-loads 'message-various '("message"))
(custom-add-loads 'gnus-group-levels '("gnus-group" "gnus-start" "gnus"))
(custom-add-loads 'gnus-summary-format '("gnus-diary" "gnus-sum" "gnus"))
(custom-add-loads 'gnus-score-decay '("gnus-score"))
(custom-add-loads 'gpg-ring '("gpg-ring"))
(custom-add-loads 'gnus-sieve '("gnus-sieve"))
(custom-add-loads 'gnus-extract-post '("gnus-uu"))
(custom-add-loads 'smime '("smime"))
(custom-add-loads 'faces '("gnus" "message"))
(custom-add-loads 'gnus-audio '("gnus-audio"))
(custom-add-loads 'spam-ifile '("spam"))
(custom-add-loads 'gnus-various '("gnus-sum" "gnus-util" "gnus"))
(custom-add-loads 'gnus-group-icons '("gnus-group"))
(custom-add-loads 'smiley '("smiley"))
(custom-add-loads 'gnus-start-server '("gnus-start"))
(custom-add-loads 'gnus-article-highlight '("gnus-art"))
(custom-add-loads 'processes '("gpg"))
(custom-add-loads 'news '("gnus" "message" "mm-decode"))
(custom-add-loads 'spam-bogofilter '("spam"))
(custom-add-loads 'gnus-diary '("gnus-diary" "nndiary"))
(custom-add-loads 'gnus-picon '("gnus-art" "gnus-picon"))
(custom-add-loads 'gnus-cache '("gnus-cache" "gnus"))
(custom-add-loads 'message-insertion '("message"))
(custom-add-loads 'message-faces '("message"))
(custom-add-loads 'gnus-score-files '("gnus-score" "gnus"))
(custom-add-loads 'spam-stat '("spam-stat"))
(custom-add-loads 'gnus-summary-marks '("gnus-sum" "gnus"))
(custom-add-loads 'nnmail-prepare '("nnmail"))
(custom-add-loads 'message-buffers '("message"))
(custom-add-loads 'gnus-article-mime '("gnus-art" "gnus-sum" "mm-uu"))
(custom-add-loads 'imap '("imap"))

;;; custom-load.el ends here
